#[non_exhaustive]pub enum ColorSpace {
Srgb,
LinearSrgb,
DisplayP3,
Rec2020,
AdobeRgb,
ProPhotoRgb,
Unknown,
}Expand description
The color space a set of RGB samples is encoded in.
A coarse, Copy tag — deliberately not a full ICC profile. It is
#[non_exhaustive]: more spaces may be added without a breaking change.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Srgb
sRGB primaries with the sRGB transfer function — standard display RGB.
LinearSrgb
sRGB primaries with a linear transfer function.
The working space of the RAW development pipeline and the documented input of the encode functions.
DisplayP3
Display P3: DCI-P3 primaries with the sRGB transfer function.
Rec2020
ITU-R BT.2020 primaries.
AdobeRgb
Adobe RGB (1998).
ProPhotoRgb
ROMM RGB / ProPhoto RGB (wide gamut).
Unknown
The color space could not be determined.
Conversions treat this as Srgb on a best-effort basis.
Implementations