#[repr(u16)]pub enum TiffType {
Show 16 variants
Byte = 1,
Ascii = 2,
Short = 3,
Long = 4,
Rational = 5,
SByte = 6,
Undefined = 7,
SShort = 8,
SLong = 9,
SRational = 10,
Float = 11,
Double = 12,
Ifd = 13,
Long8 = 16,
SLong8 = 17,
Ifd8 = 18,
}Expand description
TIFF data type codes.
These are the 12 standard data types defined by the TIFF specification, plus IFD/IFD8 for pointer types.
Variants
Byte = 1
8-bit unsigned integer
Ascii = 2
8-bit byte containing ASCII character (null-terminated)
Short = 3
16-bit unsigned integer
Long = 4
32-bit unsigned integer
Rational = 5
Two LONGs: numerator and denominator
SByte = 6
8-bit signed integer
Undefined = 7
8-bit byte that may contain anything
SShort = 8
16-bit signed integer
SLong = 9
32-bit signed integer
SRational = 10
Two SLONGs: numerator and denominator
Float = 11
Single precision IEEE floating point (4 bytes)
Double = 12
Double precision IEEE floating point (8 bytes)
Ifd = 13
32-bit unsigned integer offset to IFD
Long8 = 16
64-bit unsigned integer (BigTIFF)
SLong8 = 17
64-bit signed integer (BigTIFF)
Ifd8 = 18
64-bit unsigned integer offset to IFD (BigTIFF)
Implementations
Sourceimpl TiffType
impl TiffType
Sourcepub fn from_u16(value: u16) -> Option<Self>
pub fn from_u16(value: u16) -> Option<Self>
Parse a type code from u16, returning None for unknown types.
Sourcepub fn fits_inline(&self, count: u32) -> bool
pub fn fits_inline(&self, count: u32) -> bool
Returns whether a value of this type with the given count fits inline in an IFD entry.
Standard TIFF IFD entries have 4 bytes for the value/offset field. If the total data size fits in 4 bytes, it’s stored inline.
Sourcepub fn fits_inline_bigtiff(&self, count: u64) -> bool
pub fn fits_inline_bigtiff(&self, count: u64) -> bool
Returns whether a value of this type with the given count fits inline in a BigTIFF entry.
BigTIFF IFD entries have 8 bytes for the value/offset field.