pub enum TiffValue {
}Expand description
Container for parsed TIFF tag values.
This enum holds the actual parsed data for a tag value, with variants for each possible TIFF data type.
Variants
Bytes(Vec<u8>)
BYTE values (u8)
Ascii(String)
ASCII string (without null terminator)
Shorts(Vec<u16>)
SHORT values (u16)
Longs(Vec<u32>)
LONG values (u32)
Rationals(Vec<Rational>)
RATIONAL values
SBytes(Vec<i8>)
SBYTE values (i8)
Undefined(Vec<u8>)
UNDEFINED values (raw bytes)
SShorts(Vec<i16>)
SSHORT values (i16)
SLongs(Vec<i32>)
SLONG values (i32)
SRationals(Vec<SRational>)
SRATIONAL values
Floats(Vec<f32>)
FLOAT values (f32)
Doubles(Vec<f64>)
DOUBLE values (f64)
Long8s(Vec<u64>)
LONG8 values (u64, BigTIFF)
SLong8s(Vec<i64>)
SLONG8 values (i64, BigTIFF)
Implementations
Sourceimpl TiffValue
impl TiffValue
Sourcepub fn first_u32(&self) -> Option<u32>
pub fn first_u32(&self) -> Option<u32>
Get the first element as u32, useful for array tags like BitsPerSample.
Sourcepub fn as_u32_vec(&self) -> Option<Vec<u32>>
pub fn as_u32_vec(&self) -> Option<Vec<u32>>
Get as a Vec
Sourcepub fn as_u64_vec(&self) -> Option<Vec<u64>>
pub fn as_u64_vec(&self) -> Option<Vec<u64>>
Get as a Vec
Sourcepub fn as_f64_vec(&self) -> Option<Vec<f64>>
pub fn as_f64_vec(&self) -> Option<Vec<f64>>
Get as a Vec