Module lens_correction

Module lens_correction 

Lens distortion correction.

Implements polynomial undistortion (WarpRectilinear as specified in DNG opcode 3).

The model corrects barrel and pincushion distortion by computing, for each output pixel, the corresponding distorted source position and sampling it with bilinear interpolation.

Functions

apply_warp_rectilinear
Apply WarpRectilinear lens distortion correction.
apply_warp_rectilinear_tangential
Apply WarpRectilinear with additional tangential distortion correction.